"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureTopics = exports.defaultReplicationFactor = exports.defaultPartitionCount = void 0;
exports.defaultPartitionCount = 32;
exports.defaultReplicationFactor = 3;
/**
 * Ensures that the provided topics exist
 * The topics will be created if they do not exist
 */
async function ensureTopics(client, topics, partitions = exports.defaultPartitionCount, replicationFactor = exports.defaultReplicationFactor) {
    const topicExistsError = await new Promise((resolve) => client.topicExists(topics, (error) => (error ? resolve(error) : resolve(undefined))));
    if (!topicExistsError) {
        // no error - the topics exist
        return;
    }
    const topicsNotExistError = topicExistsError;
    if (typeof topicsNotExistError !== "object" || typeof topicsNotExistError.topics !== "object") {
        throw new TypeError(`Failed to ensure topics. ${topicExistsError}`);
    }
    // create the missing topics
    return new Promise((resolve, reject) => {
        const newTopics = Array.isArray(topicsNotExistError.topics)
            ? topicsNotExistError.topics
            : [topicsNotExistError.topics];
        client.createTopics(newTopics.map((topic) => {
            return {
                topic,
                partitions,
                replicationFactor,
            };
        }), (createTopicError, result) => {
            if (createTopicError) {
                reject(createTopicError);
            }
            else {
                const topicError = result.find((value) => value.error);
                if (topicError) {
                    reject(new Error(`Failed to create topic "${topicError.topic}". Error: ${topicError.error}`));
                }
                else {
                    resolve();
                }
            }
        });
    });
}
exports.ensureTopics = ensureTopics;
//# sourceMappingURL=kafkaTopics.js.map